import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { CarService } from '../service/car.service';
import { CDTO_car, CVO_car, FVO_car, QVO_car, UDTO_car, UVAO_car } from '../interface/car.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['车源'])
@Controller('/car')
export class CarController extends BaseController {
  @Inject()
  service: CarService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_car })
  async create(@Body() data: CDTO_car) {
    const dbData = await this.service.create(data);
    const result = new CVO_car(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_car })
  async query(@Query() filter) {
    const result = await this.service.queryList(filter);
    const data = [];
    if (result[0].data.length > 0) {
      for (const i of result[0].data) {
        const newData = new QVO_car(i);
        data.push(newData);
      }
    }
    const total = result[0].total || 0;
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_car })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_car(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_car })
  async update(@Param('id') id: string, @Body() body: UDTO_car) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
