import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { EstimateService } from '../service/estimate.service';
import { CDTO_estimate, CVO_estimate, FVO_estimate,QDTO_estimate, QVO_estimate, UDTO_estimate, UVAO_estimate } from '../interface/estimate.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['车辆估价'])
@Controller('/estimate')
export class EstimateController extends BaseController {
  @Inject()
  service: EstimateService;


@Post('/') @Validate() @ApiResponse({ type: CVO_estimate })
  async create(@Body() data: CDTO_estimate) {
    const dbData = await this.service.create(data);
    const result = new CVO_estimate(dbData);
    return result;
  }
@Get('/')@ApiQuery({name:'query'})@ApiResponse({ type: QVO_estimate })
  async query(@Query() filter:QDTO_estimate, @Query('skip') skip: number,@Query('limit') limit: number){
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_estimate(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }


@Get('/:id')@ApiResponse({ type: FVO_estimate })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_estimate(data);
    return result;
  }


@Post('/:id')@Validate()@ApiResponse({ type: UVAO_estimate })
  async update(@Param('id') id: string, @Body() body: UDTO_estimate) {
    const result = await this.service.updateOne(id, body);
    return result;
  }


@Del('/:id')@Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }


  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }


  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}

