import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ShopService } from '../service/shop.service';
import { CDTO_shop, CVO_shop, FVO_shop, QDTO_shop, QVO_shop, UDTO_shop, UVAO_shop } from '../interface/shop.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['店铺'])
@Controller('/shop')
export class ShopController extends BaseController {
  @Inject()
  service: ShopService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_shop })
  async create(@Body() data: CDTO_shop) {
    const dbData = await this.service.create(data);
    const result = new CVO_shop(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_shop })
  async query(@Query() filter: QDTO_shop, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_shop(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_shop })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_shop(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_shop })
  async update(@Param('id') id: string, @Body() body: UDTO_shop) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
