import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { BrandService } from '../../service/system/brand.service';
import { CDTO_brand, CVO_brand, FVO_brand, QDTO_brand, QVO_brand, UDTO_brand, UVAO_brand } from '../../interface/system/brand.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import get = require('lodash/get');
@ApiTags(['品牌'])
@Controller('/brand')
export class BrandController extends BaseController {
  @Inject()
  service: BrandService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_brand })
  async create(@Body() data: CDTO_brand) {
    const dbData = await this.service.create(data);
    const result = new CVO_brand(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_brand })
  async query(@Query() filter: QDTO_brand, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_brand(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/index')
  @ApiQuery({ name: 'queryIndex' })
  async queryIndex() {
    const list = await this.service.queryIndex();
    const data1 = get(list, 'data1');
    const data2 = get(list, 'data2');
    return { data1, data2 };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_brand })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_brand(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_brand })
  async update(@Param('id') id: string, @Body() body: UDTO_brand) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
